def run(sel):
    if sel=='run':
        pass
    else:
        pass
    global ai_run_ext_status_exit_action_code
    pass
    pass
    a=0
    b=0
    a=c=s=d=f=r=e=g=y=i=0

    if a!=0:
        pass

    return (a,b,c,d,e,f,g,r)


def test(sel):
    try:
        run()
    except Exception as e:
        pass

    return (123456789,45678)

class YouArePigError(BaseException):
    pass
try:
    raise YouArePigError('')
except Exception as e:
    pass
test(sel=1220092)
run()
