import turtle
print("welcome to colorspiral!")
def colorspiral(sides,bg="black"):
    t = turtle.Pen()
    turtle.bgcolor("black")
    # You can choose between 2 and 6 sides for some cool shapes!,,
    sides = 6
    colors = ["red", "yellow", "blue", "orange", "green", "purple","white"]
    for x in range(360):
        t.pencolor(colors[x%sides])
        t.forward(x * 3/sides + x)
        t.left(360/sides + 1)
        t.width(x*sides/200)
